// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDECORATION3_VERSION_H
#define KDECORATION3_VERSION_H

#define KDECORATION3_VERSION_STRING "6.6.4"
#define KDECORATION3_VERSION_MAJOR 6
#define KDECORATION3_VERSION_MINOR 6
#define KDECORATION3_VERSION_PATCH 4
#define KDECORATION3_VERSION ((6<<16)|(6<<8)|(4))

#endif
